
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter, Routes, Route } from "react-router-dom";
import { lazy, Suspense } from "react";
import ErrorBoundary from "@/components/ErrorBoundary";
import ScrollToTop from "./components/ScrollToTop";
import "./styles/serviceM8Form.css";

// Critical pages
import Index from "./pages/Index";
import IndexWithPricing from "./pages/IndexWithPricing";
import NotFound from "./pages/NotFound";

// Lazy-loaded pages
const ContactPage = lazy(() => import("./pages/ContactPage"));
const ServicePages = lazy(() => import("./components/ServicePagesGroup"));
const CustomerPages = lazy(() => import("./components/CustomerPagesGroup"));
const InfoPages = lazy(() => import("./components/InfoPagesGroup"));
const BlogPages = lazy(() => import("./components/BlogPagesGroup"));
const AboutPage = lazy(() => import("./pages/AboutPage"));
const LocationsPage = lazy(() => import("./pages/LocationsPage"));
const MouldRemovalLondon = lazy(() => import("./pages/MouldRemovalLondon"));
const TheSciencePage = lazy(() => import("./pages/TheSciencePage"));
const BoroughLandingPage = lazy(() => import("./pages/BoroughLandingPage"));
const BoroughMouldSurveyPage = lazy(() => import("./pages/BoroughMouldSurveyPage"));
const AreaLandingPage = lazy(() => import("./pages/AreaLandingPage"));
const LandlordInfoHubPage = lazy(() => import("./pages/LandlordInfoHubPage"));
const DeadlyTruthPage = lazy(() => import("./pages/DeadlyTruthPage"));
const BlogRedirect = lazy(() => import("./components/BlogRedirect"));
const UKAMEAccreditationPage = lazy(() => import("./pages/UKAMEAccreditationPage"));
const MaintenancePackagesPage = lazy(() => import("./pages/MaintenancePackagesPage"));
const CaseStudiesPage = lazy(() => import("./pages/CaseStudiesPage"));

// Simple query client with minimal configuration
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      staleTime: 5 * 60 * 1000,
      gcTime: 10 * 60 * 1000,
      refetchOnWindowFocus: false,
      retry: 1,
    },
  },
});

// Simple loading fallback
const PageLoader = () => (
  <div className="min-h-screen flex items-center justify-center">
    <div className="text-center">
      <div className="w-8 h-8 border-2 border-primary border-t-transparent rounded-full animate-spin mx-auto mb-2"></div>
      <p className="text-gray-600 text-sm">Loading...</p>
    </div>
  </div>
);

// Simple page wrapper with error boundary
const PageWrapper = ({ children }: { children: React.ReactNode }) => (
  <ErrorBoundary>
    <Suspense fallback={<PageLoader />}>
      {children}
    </Suspense>
  </ErrorBoundary>
);

function App() {
  return (
    <ErrorBoundary>
      <QueryClientProvider client={queryClient}>
        <TooltipProvider>
          <Toaster />
          <Sonner />
          <BrowserRouter>
            <ScrollToTop />
            <Routes>
              {/* Homepage - highest priority */}
              <Route path="/" element={<Index />} />
              
              {/* A/B test homepage with pricing */}
              <Route path="/pricing" element={<IndexWithPricing />} />
              
              {/* Main pages */}
              <Route path="/contact" element={
                <PageWrapper><ContactPage /></PageWrapper>
              } />
              <Route path="/about" element={
                <PageWrapper><AboutPage /></PageWrapper>
              } />
              <Route path="/locations" element={
                <PageWrapper><LocationsPage /></PageWrapper>
              } />
              <Route path="/mould-removal-london" element={
                <PageWrapper><MouldRemovalLondon /></PageWrapper>
              } />
              <Route path="/the-science" element={
                <PageWrapper><TheSciencePage /></PageWrapper>
              } />
              <Route path="/landlord-guide" element={
                <PageWrapper><LandlordInfoHubPage /></PageWrapper>
              } />
              <Route path="/why-cheap-mould-remediation-makes-the-problem-worse" element={
                <PageWrapper><DeadlyTruthPage /></PageWrapper>
              } />
              <Route path="/ukame-accreditation" element={
                <PageWrapper><UKAMEAccreditationPage /></PageWrapper>
              } />
              <Route path="/maintenance-packages" element={
                <PageWrapper><MaintenancePackagesPage /></PageWrapper>
              } />
              <Route path="/case-studies" element={
                <PageWrapper><CaseStudiesPage /></PageWrapper>
              } />
              
              {/* Location pages */}
              <Route path="/locations/:locationSlug" element={
                <PageWrapper><AreaLandingPage /></PageWrapper>
              } />
              <Route path="/locations/london/:boroughSlug" element={
                <PageWrapper><BoroughLandingPage /></PageWrapper>
              } />
              <Route path="/locations/london/:boroughSlug/mould-survey" element={
                <PageWrapper><BoroughMouldSurveyPage /></PageWrapper>
              } />
              
              {/* Service pages */}
              <Route path="/services/*" element={
                <PageWrapper><ServicePages /></PageWrapper>
              } />
              
              {/* Customer pages */}
              <Route path="/customers/*" element={
                <PageWrapper><CustomerPages /></PageWrapper>
              } />
              
              {/* Blog pages */}
              <Route path="/blog/*" element={
                <PageWrapper><BlogPages /></PageWrapper>
              } />
              
              {/* Blog redirects for legacy URLs - fix route patterns */}
              <Route path="/mould-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/what-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/how-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/can-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/is-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/diy-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/black-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/landlord-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/the-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              
              {/* Additional blog redirect patterns for comprehensive coverage */}
              <Route path="/essential-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/effects-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/seasonal-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/hidden-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/climate-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/tenants-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/guide-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/prevent-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/understanding-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              <Route path="/comprehensive-/*" element={
                <PageWrapper><BlogRedirect /></PageWrapper>
              } />
              
              {/* Info pages - must come after specific routes */}
              <Route path="/*" element={
                <PageWrapper><InfoPages /></PageWrapper>
              } />
              
              {/* 404 fallback - must be last */}
              <Route path="*" element={<NotFound />} />
            </Routes>
          </BrowserRouter>
        </TooltipProvider>
      </QueryClientProvider>
    </ErrorBoundary>
  );
}

export default App;
